@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
-
 """
 ko custom locale file.
 """
+from __future__ import annotations
+
 
 translations = {
     # Relative time
